/* libvirt-broker.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from libvirt-broker.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gconfig/libvirt-gconfig.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesLibvirtBrokerPrivate BoxesLibvirtBrokerPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesLibvirtBrokerAddDomainData BoxesLibvirtBrokerAddDomainData;
typedef struct _BoxesLibvirtBrokerTryAddNewDomainData BoxesLibvirtBrokerTryAddNewDomainData;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_VM_IMPORTER (boxes_vm_importer_get_type ())
#define BOXES_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporter))
#define BOXES_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))
#define BOXES_IS_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_IMPORTER))
#define BOXES_IS_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_IMPORTER))
#define BOXES_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))

typedef struct _BoxesVMImporter BoxesVMImporter;
typedef struct _BoxesVMImporterClass BoxesVMImporterClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER (boxes_libvirt_system_vm_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporter))
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_VM_IMPORTER, BoxesLibvirtSystemVMImporterClass))

typedef struct _BoxesLibvirtSystemVMImporter BoxesLibvirtSystemVMImporter;
typedef struct _BoxesLibvirtSystemVMImporterClass BoxesLibvirtSystemVMImporterClass;
typedef struct _BoxesLibvirtBrokerTryAddExistingDomainData BoxesLibvirtBrokerTryAddExistingDomainData;
typedef struct _Block30Data Block30Data;
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesLibvirtBrokerAddSourceData BoxesLibvirtBrokerAddSourceData;

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

struct _BoxesLibvirtBroker {
	BoxesBroker parent_instance;
	BoxesLibvirtBrokerPrivate * priv;
};

struct _BoxesLibvirtBrokerClass {
	BoxesBrokerClass parent_class;
};

struct _BoxesLibvirtBrokerPrivate {
	GHashTable* connections;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesLibvirtBrokerAddDomainData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	GVirConnection* connection;
	GVirDomain* domain;
	BoxesLibvirtMachine* result;
	BoxesLibvirtBroker* _tmp0_;
	BoxesLibvirtMachine* machine;
	GVirDomain* _tmp1_;
	gconstpointer _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	BoxesLibvirtMachine* _tmp5_;
	BoxesCollectionSource* _tmp6_;
	GVirConnection* _tmp7_;
	GVirDomain* _tmp8_;
	BoxesLibvirtMachine* _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	GVirConnection* _tmp12_;
	BoxesApp* _tmp13_;
	GVirConnection* _tmp14_;
	GVirConnection* _tmp15_;
	GVirConnection* _tmp16_;
	BoxesApp* _tmp17_;
	BoxesCollection* _tmp18_;
	BoxesLibvirtMachine* _tmp19_;
	GVirDomain* _tmp20_;
	BoxesLibvirtMachine* _tmp21_;
	BoxesLibvirtMachine* _tmp22_;
	BoxesCollectionSource* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gboolean _tmp27_;
	GVirConfigDomain* config;
	BoxesLibvirtMachine* _tmp28_;
	GVirDomain* _tmp29_;
	GVirDomain* _tmp30_;
	GVirConfigDomain* _tmp31_;
	GVirConfigDomain* _tmp32_;
	GVirConnection* _tmp33_;
	BoxesLibvirtMachine* _tmp34_;
	GVirDomain* _tmp35_;
	GVirDomain* _tmp36_;
	GVirConfigDomain* _tmp37_;
	GError* e;
	GVirDomain* _tmp38_;
	const gchar* _tmp39_;
	GError* _tmp40_;
	const gchar* _tmp41_;
	GError * _inner_error_;
};

struct _BoxesLibvirtBrokerTryAddNewDomainData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	GVirConnection* connection;
	GVirDomain* domain;
	BoxesCollectionSource* _tmp0_;
	GVirConnection* _tmp1_;
	GVirDomain* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	BoxesLibvirtMachine* _tmp4_;
	GError* _error_;
	BoxesCollectionSource* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GError* _tmp9_;
	const gchar* _tmp10_;
	GError * _inner_error_;
};

struct _BoxesLibvirtBrokerTryAddExistingDomainData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	GVirConnection* connection;
	GVirDomain* domain;
	BoxesLibvirtMachine* machine;
	BoxesCollectionSource* _tmp0_;
	GVirConnection* _tmp1_;
	GVirDomain* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	GVirConfigDomain* config;
	GVirConfigDomain* _tmp4_;
	GVirConfigDomain* _tmp5_;
	GVirConfigDomain* _tmp6_;
	gboolean _tmp7_;
	GVirConfigDomain* _tmp8_;
	gboolean _tmp9_;
	GVirConfigDomain* _tmp10_;
	gboolean _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	BoxesVMCreator* _tmp14_;
	BoxesVMCreator* _tmp15_;
	GVirConfigDomain* _tmp16_;
	gboolean _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	BoxesVMImporter* _tmp20_;
	BoxesVMImporter* _tmp21_;
	GVirConfigDomain* _tmp22_;
	gboolean _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesLibvirtSystemVMImporter* _tmp26_;
	BoxesLibvirtSystemVMImporter* _tmp27_;
	GError* _error_;
	BoxesCollectionSource* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	GError* _tmp32_;
	const gchar* _tmp33_;
	GError * _inner_error_;
};

struct _Block30Data {
	int _ref_count_;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	gpointer _async_data_;
};

struct _BoxesLibvirtBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtBroker* self;
	BoxesCollectionSource* source;
	Block30Data* _data30_;
	BoxesCollectionSource* _tmp0_;
	GHashTable* _tmp1_;
	BoxesCollectionSource* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gconstpointer _tmp6_;
	gboolean _tmp7_;
	GVirConnection* connection;
	BoxesCollectionSource* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	GVirConnection* _tmp12_;
	GVirConnection* _tmp13_;
	GVirConnection* _tmp14_;
	GVirConnection* _tmp15_;
	GVirConnection* _tmp16_;
	GVirStoragePool* pool;
	GVirConnection* _tmp17_;
	GVirStoragePool* _tmp18_;
	GVirStoragePool* _tmp19_;
	GVirStoragePool* _tmp20_;
	GVirStoragePoolInfo* _tmp21_;
	GVirStoragePool* _tmp22_;
	GVirStoragePoolInfo* _tmp23_;
	GVirStoragePoolInfo* _tmp24_;
	GVirStoragePoolInfo* _tmp25_;
	GVirStoragePoolState _tmp26_;
	gboolean _tmp27_;
	GVirStoragePool* _tmp28_;
	GVirStoragePool* _tmp29_;
	GError* _error_;
	GError* _tmp30_;
	const gchar* _tmp31_;
	GHashTable* _tmp32_;
	BoxesCollectionSource* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	GVirConnection* _tmp36_;
	GVirConnection* _tmp37_;
	GVirConnection* _tmp38_;
	GList* _tmp39_;
	GList* domain_collection;
	GList* domain_it;
	GVirDomain* _tmp40_;
	GVirDomain* domain;
	BoxesCollectionSource* _tmp41_;
	GVirConnection* _tmp42_;
	GVirDomain* _tmp43_;
	GVirConnection* _tmp44_;
	GVirConnection* _tmp45_;
	BoxesCollectionSource* _tmp46_;
	GError * _inner_error_;
};


static gpointer boxes_libvirt_broker_parent_class = NULL;
static BoxesLibvirtBroker* boxes_libvirt_broker_broker;
static BoxesLibvirtBroker* boxes_libvirt_broker_broker = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_BROKER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerPrivate))
enum  {
	BOXES_LIBVIRT_BROKER_DUMMY_PROPERTY
};
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
static BoxesLibvirtBroker* boxes_libvirt_broker_new (void);
static BoxesLibvirtBroker* boxes_libvirt_broker_construct (GType object_type);
BoxesBroker* boxes_broker_construct (GType object_type);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name);
static void boxes_libvirt_broker_add_domain_data_free (gpointer _data);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
void boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_broker_add_domain_co (BoxesLibvirtBrokerAddDomainData* _data_);
BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
#define BOXES_APP_DEFAULT_SOURCE_NAME "QEMU Session"
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
void boxes_vm_configurator_update_existing_domain (GVirConfigDomain* domain, GVirConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_vm_configurator_update_existing_domain_finish (GAsyncResult* _res_);
static void boxes_libvirt_broker_add_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_broker_try_add_new_domain_data_free (gpointer _data);
static void boxes_libvirt_broker_try_add_new_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_broker_try_add_new_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_broker_try_add_new_domain_co (BoxesLibvirtBrokerTryAddNewDomainData* _data_);
static void boxes_libvirt_broker_try_add_new_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_broker_try_add_existing_domain_data_free (gpointer _data);
static void boxes_libvirt_broker_try_add_existing_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_broker_try_add_existing_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_broker_try_add_existing_domain_co (BoxesLibvirtBrokerTryAddExistingDomainData* _data_);
static void boxes_libvirt_broker_try_add_existing_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
gboolean boxes_vm_configurator_is_import_config (GVirConfigDomain* domain);
BoxesVMImporter* boxes_vm_importer_new_for_import_completion (BoxesLibvirtMachine* machine);
BoxesVMImporter* boxes_vm_importer_construct_for_import_completion (GType object_type, BoxesLibvirtMachine* machine);
GType boxes_vm_importer_get_type (void) G_GNUC_CONST;
gboolean boxes_vm_configurator_is_libvirt_system_import_config (GVirConfigDomain* domain);
BoxesLibvirtSystemVMImporter* boxes_libvirt_system_vm_importer_new_for_import_completion (BoxesLibvirtMachine* machine);
BoxesLibvirtSystemVMImporter* boxes_libvirt_system_vm_importer_construct_for_import_completion (GType object_type, BoxesLibvirtMachine* machine);
GType boxes_libvirt_system_vm_importer_get_type (void) G_GNUC_CONST;
static void boxes_libvirt_broker_real_add_source_data_free (gpointer _data);
static void boxes_libvirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_broker_real_add_source_co (BoxesLibvirtBrokerAddSourceData* _data_);
static Block30Data* block30_data_ref (Block30Data* _data30_);
static void block30_data_unref (void * _userdata_);
static void boxes_libvirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static void _g_list_free__g_object_unref0_ (GList* self);
static void __lambda12_ (BoxesLibvirtBroker* self, GVirConnection* connection, GVirDomain* domain);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
static void ___lambda12__gvir_connection_domain_removed (GVirConnection* _sender, GVirDomain* dom, gpointer self);
static void __lambda80_ (Block30Data* _data30_, GVirConnection* connection, GVirDomain* domain);
static void ___lambda80__gvir_connection_domain_added (GVirConnection* _sender, GVirDomain* dom, gpointer self);
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static void boxes_libvirt_broker_finalize (GObject* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return self ? g_object_ref (self) : NULL;
#line 590 "libvirt-broker.c"
}


BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void) {
	BoxesLibvirtBroker* result = NULL;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp2_ = NULL;
	BoxesLibvirtBroker* _tmp3_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = boxes_libvirt_broker_broker;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_tmp0_ == NULL) {
#line 603 "libvirt-broker.c"
		BoxesLibvirtBroker* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_tmp1_ = boxes_libvirt_broker_new ();
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (boxes_libvirt_broker_broker);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_libvirt_broker_broker = _tmp1_;
#line 611 "libvirt-broker.c"
	}
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = boxes_libvirt_broker_broker;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = _tmp3_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 621 "libvirt-broker.c"
}


static void _g_free0_ (gpointer var) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	var = (g_free (var), NULL);
#line 628 "libvirt-broker.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 635 "libvirt-broker.c"
}


static BoxesLibvirtBroker* boxes_libvirt_broker_construct (GType object_type) {
	BoxesLibvirtBroker * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = (BoxesLibvirtBroker*) boxes_broker_construct (object_type);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = g_str_hash;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = g_str_equal;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_hash_table_unref0 (self->priv->connections);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self->priv->connections = _tmp2_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return self;
#line 658 "libvirt-broker.c"
}


static BoxesLibvirtBroker* boxes_libvirt_broker_new (void) {
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return boxes_libvirt_broker_construct (BOXES_TYPE_LIBVIRT_BROKER);
#line 665 "libvirt-broker.c"
}


GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name) {
	GVirConnection* result = NULL;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gconstpointer _tmp4_ = NULL;
	GVirConnection* _tmp5_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = boxes_libvirt_broker_broker;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (_tmp0_ != NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = boxes_libvirt_broker_broker;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _tmp1_->priv->connections;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = name;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = g_hash_table_lookup (_tmp2_, _tmp3_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = _g_object_ref0 ((GVirConnection*) _tmp4_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = _tmp5_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 699 "libvirt-broker.c"
}


static void boxes_libvirt_broker_add_domain_data_free (gpointer _data) {
	BoxesLibvirtBrokerAddDomainData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_slice_free (BoxesLibvirtBrokerAddDomainData, _data_);
#line 718 "libvirt-broker.c"
}


void boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtBrokerAddDomainData* _data_;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
	GVirConnection* _tmp4_ = NULL;
	GVirDomain* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_slice_new0 (BoxesLibvirtBrokerAddDomainData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_broker_add_domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_broker_add_domain_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->source = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = connection;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->connection = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = domain;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->domain = _tmp6_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_add_domain_co (_data_);
#line 767 "libvirt-broker.c"
}


BoxesLibvirtMachine* boxes_libvirt_broker_add_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesLibvirtBrokerAddDomainData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return NULL;
#line 778 "libvirt-broker.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return result;
#line 788 "libvirt-broker.c"
}


static void boxes_libvirt_broker_add_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtBrokerAddDomainData* _data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = _user_data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_res_ = _res_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_add_domain_co (_data_);
#line 802 "libvirt-broker.c"
}


static gboolean boxes_libvirt_broker_add_domain_co (BoxesLibvirtBrokerAddDomainData* _data_) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	switch (_data_->_state_) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 0:
#line 811 "libvirt-broker.c"
		goto _state_0;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 1:
#line 815 "libvirt-broker.c"
		goto _state_1;
		default:
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_assert_not_reached ();
#line 820 "libvirt-broker.c"
	}
	_state_0:
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = boxes_libvirt_broker_broker;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (_data_->_tmp0_ != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = _data_->domain;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = g_object_get_data ((GObject*) _data_->_tmp1_, "machine");
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = _g_object_ref0 ((BoxesLibvirtMachine*) _data_->_tmp2_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->machine = _data_->_tmp3_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = _data_->machine;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_tmp4_ != NULL) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->result = _data_->machine;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 855 "libvirt-broker.c"
		} else {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 859 "libvirt-broker.c"
		}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 865 "libvirt-broker.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = _data_->source;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = _data_->connection;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = _data_->domain;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = boxes_libvirt_machine_new (_data_->_tmp6_, _data_->_tmp7_, _data_->_tmp8_, &_data_->_inner_error_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = _data_->_tmp9_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_error_free (_data_->_inner_error_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->machine);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 897 "libvirt-broker.c"
		} else {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 901 "libvirt-broker.c"
		}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 907 "libvirt-broker.c"
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = _data_->_tmp5_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->machine);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->machine = _data_->_tmp10_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = _data_->machine;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = _data_->connection;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = boxes_app_app;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp14_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp14_ = boxes_app_get_default_connection (_data_->_tmp13_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp15_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp16_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	((BoxesMachine*) _data_->_tmp11_)->suspend_at_exit = _data_->_tmp12_ == _data_->_tmp16_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->_tmp16_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp17_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp17_ = boxes_app_app;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp18_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp18_ = _data_->_tmp17_->collection;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp19_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp19_ = _data_->machine;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_collection_add_item (_data_->_tmp18_, (BoxesCollectionItem*) _data_->_tmp19_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp20_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp20_ = _data_->domain;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp21_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp21_ = _data_->machine;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp22_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp22_ = _g_object_ref0 (_data_->_tmp21_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_set_data_full ((GObject*) _data_->_tmp20_, "machine", _data_->_tmp22_, g_object_unref);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp23_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp23_ = _data_->source;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp24_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp24_ = boxes_collection_source_get_name (_data_->_tmp23_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp25_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp26_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp27_ = FALSE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp27_ = g_strcmp0 (_data_->_tmp26_, BOXES_APP_DEFAULT_SOURCE_NAME) != 0;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_free0 (_data_->_tmp26_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_tmp27_) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->result = _data_->machine;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->_tmp5_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1007 "libvirt-broker.c"
		} else {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1011 "libvirt-broker.c"
		}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1017 "libvirt-broker.c"
	}
	{
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = _data_->machine;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = boxes_libvirt_machine_get_domain (_data_->_tmp28_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = _data_->_tmp29_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = gvir_domain_get_config (_data_->_tmp30_, (guint) 0, &_data_->_inner_error_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->config = _data_->_tmp31_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1040 "libvirt-broker.c"
			goto __catch12_g_error;
		}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp32_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp32_ = _data_->config;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp33_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp33_ = _data_->connection;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 1;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_vm_configurator_update_existing_domain (_data_->_tmp32_, _data_->_tmp33_, boxes_libvirt_broker_add_domain_ready, _data_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1057 "libvirt-broker.c"
		_state_1:
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_vm_configurator_update_existing_domain_finish (_data_->_res_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp34_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp34_ = _data_->machine;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp35_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp35_ = boxes_libvirt_machine_get_domain (_data_->_tmp34_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp36_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp37_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp37_ = _data_->config;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_domain_set_config (_data_->_tmp36_, _data_->_tmp37_, &_data_->_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_g_object_unref0 (_data_->config);
#line 1083 "libvirt-broker.c"
			goto __catch12_g_error;
		}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->config);
#line 1088 "libvirt-broker.c"
	}
	goto __finally12;
	__catch12_g_error:
	{
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->e = _data_->_inner_error_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp38_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp38_ = _data_->domain;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp39_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp39_ = gvir_domain_get_name (_data_->_tmp38_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp40_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp40_ = _data_->e;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp41_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp41_ = _data_->_tmp40_->message;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:47: Failed to update domain '%s': %s", _data_->_tmp39_, _data_->_tmp41_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_data_->e);
#line 1117 "libvirt-broker.c"
	}
	__finally12:
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_error_free (_data_->_inner_error_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->_tmp5_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->machine);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1134 "libvirt-broker.c"
		} else {
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1138 "libvirt-broker.c"
		}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1144 "libvirt-broker.c"
	}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->result = _data_->machine;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->_tmp5_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1154 "libvirt-broker.c"
	} else {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1158 "libvirt-broker.c"
	}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->_tmp5_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->machine);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1172 "libvirt-broker.c"
	} else {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1176 "libvirt-broker.c"
	}
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 1182 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_new_domain_data_free (gpointer _data) {
	BoxesLibvirtBrokerTryAddNewDomainData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_slice_free (BoxesLibvirtBrokerTryAddNewDomainData, _data_);
#line 1199 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_new_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtBrokerTryAddNewDomainData* _data_;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
	GVirConnection* _tmp4_ = NULL;
	GVirDomain* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_slice_new0 (BoxesLibvirtBrokerTryAddNewDomainData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_broker_try_add_new_domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_broker_try_add_new_domain_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->source = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = connection;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->connection = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = domain;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->domain = _tmp6_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_new_domain_co (_data_);
#line 1248 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_new_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_) {
	BoxesLibvirtBrokerTryAddNewDomainData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1256 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_new_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtBrokerTryAddNewDomainData* _data_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = _user_data_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_res_ = _res_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_new_domain_co (_data_);
#line 1270 "libvirt-broker.c"
}


static gboolean boxes_libvirt_broker_try_add_new_domain_co (BoxesLibvirtBrokerTryAddNewDomainData* _data_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	switch (_data_->_state_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 0:
#line 1279 "libvirt-broker.c"
		goto _state_0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 1:
#line 1283 "libvirt-broker.c"
		goto _state_1;
		default:
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_assert_not_reached ();
#line 1288 "libvirt-broker.c"
	}
	_state_0:
	{
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp0_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp0_ = _data_->source;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp1_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp1_ = _data_->connection;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp2_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp2_ = _data_->domain;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 1;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_libvirt_broker_add_domain (_data_->self, _data_->_tmp0_, _data_->_tmp1_, _data_->_tmp2_, boxes_libvirt_broker_try_add_new_domain_ready, _data_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1310 "libvirt-broker.c"
		_state_1:
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp3_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp3_ = boxes_libvirt_broker_add_domain_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp4_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1324 "libvirt-broker.c"
			goto __catch13_g_error;
		}
	}
	goto __finally13;
	__catch13_g_error:
	{
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp5_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp5_ = _data_->source;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp6_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp6_ = boxes_collection_source_get_name (_data_->_tmp5_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp7_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp8_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp9_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp9_ = _data_->_error_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp10_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp10_ = _data_->_tmp9_->message;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:58: Failed to create source '%s': %s", _data_->_tmp8_, _data_->_tmp10_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_free0 (_data_->_tmp8_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_data_->_error_);
#line 1365 "libvirt-broker.c"
	}
	__finally13:
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1376 "libvirt-broker.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1382 "libvirt-broker.c"
	} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1386 "libvirt-broker.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 1392 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_existing_domain_data_free (gpointer _data) {
	BoxesLibvirtBrokerTryAddExistingDomainData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_slice_free (BoxesLibvirtBrokerTryAddExistingDomainData, _data_);
#line 1409 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_existing_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtBrokerTryAddExistingDomainData* _data_;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
	GVirConnection* _tmp4_ = NULL;
	GVirDomain* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_slice_new0 (BoxesLibvirtBrokerTryAddExistingDomainData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_broker_try_add_existing_domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_broker_try_add_existing_domain_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->source = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = connection;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->connection = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = domain;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->domain);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->domain = _tmp6_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_existing_domain_co (_data_);
#line 1458 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_existing_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_) {
	BoxesLibvirtBrokerTryAddExistingDomainData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1466 "libvirt-broker.c"
}


static void boxes_libvirt_broker_try_add_existing_domain_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtBrokerTryAddExistingDomainData* _data_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = _user_data_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_res_ = _res_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_existing_domain_co (_data_);
#line 1480 "libvirt-broker.c"
}


static gboolean boxes_libvirt_broker_try_add_existing_domain_co (BoxesLibvirtBrokerTryAddExistingDomainData* _data_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	switch (_data_->_state_) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 0:
#line 1489 "libvirt-broker.c"
		goto _state_0;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 1:
#line 1493 "libvirt-broker.c"
		goto _state_1;
		default:
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_assert_not_reached ();
#line 1498 "libvirt-broker.c"
	}
	_state_0:
	{
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp0_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp0_ = _data_->source;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp1_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp1_ = _data_->connection;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp2_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp2_ = _data_->domain;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 1;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		boxes_libvirt_broker_add_domain (_data_->self, _data_->_tmp0_, _data_->_tmp1_, _data_->_tmp2_, boxes_libvirt_broker_try_add_existing_domain_ready, _data_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1520 "libvirt-broker.c"
		_state_1:
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp3_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp3_ = boxes_libvirt_broker_add_domain_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->machine = _data_->_tmp3_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1530 "libvirt-broker.c"
			goto __catch14_g_error;
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp4_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp4_ = boxes_libvirt_machine_get_domain_config (_data_->machine);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp5_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp6_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->config = _data_->_tmp6_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp8_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp8_ = _data_->config;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp9_ = FALSE;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp9_ = boxes_vm_configurator_is_install_config (_data_->_tmp8_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_tmp9_) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp7_ = TRUE;
#line 1559 "libvirt-broker.c"
		} else {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp10_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp10_ = _data_->config;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp11_ = FALSE;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp11_ = boxes_vm_configurator_is_live_config (_data_->_tmp10_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp7_ = _data_->_tmp11_;
#line 1571 "libvirt-broker.c"
		}
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_tmp7_) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp12_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp12_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->machine);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp13_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp13_ = _data_->_tmp12_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_debug ("libvirt-broker.vala:72: Continuing installation/live session for '%s'," \
" ..", _data_->_tmp13_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp14_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp14_ = boxes_vm_creator_new_for_install_completion (_data_->machine);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp15_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp15_ = _data_->_tmp14_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_boxes_vm_creator_unref0 (_data_->_tmp15_);
#line 1595 "libvirt-broker.c"
		} else {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp16_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp16_ = _data_->config;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp17_ = FALSE;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp17_ = boxes_vm_configurator_is_import_config (_data_->_tmp16_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_data_->_tmp17_) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp18_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp18_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->machine);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp19_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp19_ = _data_->_tmp18_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				g_debug ("libvirt-broker.vala:75: Continuing import of '%s', ..", _data_->_tmp19_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp20_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp20_ = boxes_vm_importer_new_for_import_completion (_data_->machine);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp21_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_boxes_vm_creator_unref0 (_data_->_tmp21_);
#line 1627 "libvirt-broker.c"
			} else {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp22_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp22_ = _data_->config;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp23_ = FALSE;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp23_ = boxes_vm_configurator_is_libvirt_system_import_config (_data_->_tmp22_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				if (_data_->_tmp23_) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp24_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->machine);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp25_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp25_ = _data_->_tmp24_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					g_debug ("libvirt-broker.vala:78: Continuing import of '%s', ..", _data_->_tmp25_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp26_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp26_ = boxes_libvirt_system_vm_importer_new_for_import_completion (_data_->machine);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp27_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_data_->_tmp27_ = _data_->_tmp26_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_boxes_vm_creator_unref0 (_data_->_tmp27_);
#line 1659 "libvirt-broker.c"
				}
			}
		}
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->config);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->machine);
#line 1667 "libvirt-broker.c"
	}
	goto __finally14;
	__catch14_g_error:
	{
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp28_ = _data_->source;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp29_ = boxes_collection_source_get_name (_data_->_tmp28_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = _data_->_tmp29_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = _data_->_tmp30_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp32_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp32_ = _data_->_error_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp33_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp33_ = _data_->_tmp32_->message;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:82: Failed to create source '%s': %s", _data_->_tmp31_, _data_->_tmp33_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_free0 (_data_->_tmp31_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_data_->_error_);
#line 1706 "libvirt-broker.c"
	}
	__finally14:
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_data_->_inner_error_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 1717 "libvirt-broker.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1723 "libvirt-broker.c"
	} else {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1727 "libvirt-broker.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 1733 "libvirt-broker.c"
}


static void boxes_libvirt_broker_real_add_source_data_free (gpointer _data) {
	BoxesLibvirtBrokerAddSourceData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_slice_free (BoxesLibvirtBrokerAddSourceData, _data_);
#line 1744 "libvirt-broker.c"
}


static void boxes_libvirt_broker_real_add_source (BoxesBroker* base, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtBroker * self;
	BoxesLibvirtBrokerAddSourceData* _data_;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = (BoxesLibvirtBroker*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_slice_new0 (BoxesLibvirtBrokerAddSourceData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_broker_real_add_source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_broker_real_add_source_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->source);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->source = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_real_add_source_co (_data_);
#line 1776 "libvirt-broker.c"
}


static void boxes_libvirt_broker_real_add_source_finish (BoxesBroker* base, GAsyncResult* _res_) {
	BoxesLibvirtBrokerAddSourceData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1784 "libvirt-broker.c"
}


static Block30Data* block30_data_ref (Block30Data* _data30_) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_atomic_int_inc (&_data30_->_ref_count_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return _data30_;
#line 1793 "libvirt-broker.c"
}


static void block30_data_unref (void * _userdata_) {
	Block30Data* _data30_;
	_data30_ = (Block30Data*) _userdata_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (g_atomic_int_dec_and_test (&_data30_->_ref_count_)) {
#line 1802 "libvirt-broker.c"
		BoxesLibvirtBroker* self;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		self = _data30_->self;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data30_->source);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_slice_free (Block30Data, _data30_);
#line 1812 "libvirt-broker.c"
	}
}


static void boxes_libvirt_broker_add_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtBrokerAddSourceData* _data_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_ = _user_data_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_source_object_ = source_object;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_res_ = _res_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_real_add_source_co (_data_);
#line 1827 "libvirt-broker.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 1834 "libvirt-broker.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_list_free (self);
#line 1843 "libvirt-broker.c"
}


static void __lambda12_ (BoxesLibvirtBroker* self, GVirConnection* connection, GVirDomain* domain) {
	BoxesLibvirtMachine* machine = NULL;
	GVirDomain* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	BoxesApp* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = domain;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "machine");
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _g_object_ref0 ((BoxesLibvirtMachine*) _tmp1_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	machine = _tmp2_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = machine;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_tmp3_ == NULL) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (machine);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return;
#line 1875 "libvirt-broker.c"
	}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = boxes_app_app;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp5_ = machine;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_app_delete_machine (_tmp4_, (BoxesMachine*) _tmp5_, FALSE);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (machine);
#line 1885 "libvirt-broker.c"
}


static void ___lambda12__gvir_connection_domain_removed (GVirConnection* _sender, GVirDomain* dom, gpointer self) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	__lambda12_ ((BoxesLibvirtBroker*) self, _sender, dom);
#line 1892 "libvirt-broker.c"
}


static void __lambda80_ (Block30Data* _data30_, GVirConnection* connection, GVirDomain* domain) {
	BoxesLibvirtBroker* self;
	GVirDomain* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = _data30_->self;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (connection != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_return_if_fail (domain != NULL);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp0_ = domain;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp1_ = gvir_domain_get_name (_tmp0_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_debug ("libvirt-broker.vala:122: New domain '%s'", _tmp1_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp2_ = _data30_->source;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp3_ = connection;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_tmp4_ = domain;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_try_add_new_domain (self, _tmp2_, _tmp3_, _tmp4_, NULL, NULL);
#line 1923 "libvirt-broker.c"
}


static void ___lambda80__gvir_connection_domain_added (GVirConnection* _sender, GVirDomain* dom, gpointer self) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	__lambda80_ (self, _sender, dom);
#line 1930 "libvirt-broker.c"
}


static gboolean boxes_libvirt_broker_real_add_source_co (BoxesLibvirtBrokerAddSourceData* _data_) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	switch (_data_->_state_) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 0:
#line 1939 "libvirt-broker.c"
		goto _state_0;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 1:
#line 1943 "libvirt-broker.c"
		goto _state_1;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 2:
#line 1947 "libvirt-broker.c"
		goto _state_2;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 3:
#line 1951 "libvirt-broker.c"
		goto _state_3;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 4:
#line 1955 "libvirt-broker.c"
		goto _state_4;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 5:
#line 1959 "libvirt-broker.c"
		goto _state_5;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 6:
#line 1963 "libvirt-broker.c"
		goto _state_6;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		case 7:
#line 1967 "libvirt-broker.c"
		goto _state_7;
		default:
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_assert_not_reached ();
#line 1972 "libvirt-broker.c"
	}
	_state_0:
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_ = g_slice_new0 (Block30Data);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_->_ref_count_ = 1;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_->self = g_object_ref (_data_->self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp0_ = _data_->source;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->_data30_->source);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_->source = _data_->_tmp0_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_->_async_data_ = _data_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp1_ = _data_->self->priv->connections;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp2_ = _data_->_data30_->source;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp3_ = boxes_collection_source_get_name (_data_->_tmp2_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp6_ = g_hash_table_lookup (_data_->_tmp1_, _data_->_tmp5_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = FALSE;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp7_ = ((GVirConnection*) _data_->_tmp6_) != NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_free0 (_data_->_tmp5_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_tmp7_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		block30_data_unref (_data_->_data30_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_data30_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_state_ == 0) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2031 "libvirt-broker.c"
		} else {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2035 "libvirt-broker.c"
		}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_object_unref (_data_->_async_result);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 2041 "libvirt-broker.c"
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp8_ = _data_->_data30_->source;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp9_ = boxes_collection_source_get_uri (_data_->_tmp8_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp12_ = gvir_connection_new (_data_->_tmp11_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_free0 (_data_->_tmp11_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->connection = _data_->_tmp13_;
#line 2071 "libvirt-broker.c"
	{
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp14_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp14_ = _data_->connection;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 1;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_open_async (_data_->_tmp14_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 2083 "libvirt-broker.c"
		_state_1:
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_open_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2089 "libvirt-broker.c"
			goto __catch15_g_error;
		}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp15_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp15_ = _data_->connection;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 2;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_domains_async (_data_->_tmp15_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 2102 "libvirt-broker.c"
		_state_2:
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_domains_finish (_data_->_tmp15_, _data_->_res_, &_data_->_inner_error_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2108 "libvirt-broker.c"
			goto __catch15_g_error;
		}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp16_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp16_ = _data_->connection;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_state_ = 3;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_storage_pools_async (_data_->_tmp16_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 2121 "libvirt-broker.c"
		_state_3:
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		gvir_connection_fetch_storage_pools_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2127 "libvirt-broker.c"
			goto __catch15_g_error;
		}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp17_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp17_ = _data_->connection;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp18_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp18_ = boxes_get_storage_pool (_data_->_tmp17_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->pool = _data_->_tmp18_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp19_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp19_ = _data_->pool;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		if (_data_->_tmp19_ != NULL) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp20_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp20_ = _data_->pool;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			gvir_storage_pool_set_autostart (_data_->_tmp20_, TRUE, &_data_->_inner_error_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->pool);
#line 2156 "libvirt-broker.c"
				goto __catch15_g_error;
			}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp22_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp22_ = _data_->pool;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp23_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp23_ = gvir_storage_pool_get_info (_data_->_tmp22_, &_data_->_inner_error_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp21_ = _data_->_tmp23_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->pool);
#line 2173 "libvirt-broker.c"
				goto __catch15_g_error;
			}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp24_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp24_ = _data_->_tmp21_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp21_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp25_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp26_ = 0;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp26_ = _data_->_tmp25_->state;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp27_ = FALSE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp27_ = _data_->_tmp26_ == GVIR_STORAGE_POOL_STATE_INACTIVE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			__vala_GVirStoragePoolInfo_free0 (_data_->_tmp25_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (_data_->_tmp27_) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp28_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp28_ = _data_->pool;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_state_ = 4;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				gvir_storage_pool_start_async (_data_->_tmp28_, (guint) 0, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				return FALSE;
#line 2208 "libvirt-broker.c"
				_state_4:
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				gvir_storage_pool_start_finish (_data_->_tmp28_, _data_->_res_, &_data_->_inner_error_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					__vala_GVirStoragePoolInfo_free0 (_data_->_tmp21_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
					_g_object_unref0 (_data_->pool);
#line 2218 "libvirt-broker.c"
					goto __catch15_g_error;
				}
			}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp29_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp29_ = _data_->pool;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_state_ = 5;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			gvir_storage_pool_refresh_async (_data_->_tmp29_, NULL, boxes_libvirt_broker_add_source_ready, _data_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			return FALSE;
#line 2232 "libvirt-broker.c"
			_state_5:
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			gvir_storage_pool_refresh_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				__vala_GVirStoragePoolInfo_free0 (_data_->_tmp21_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->pool);
#line 2242 "libvirt-broker.c"
				goto __catch15_g_error;
			}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			__vala_GVirStoragePoolInfo_free0 (_data_->_tmp21_);
#line 2247 "libvirt-broker.c"
		}
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->pool);
#line 2251 "libvirt-broker.c"
	}
	goto __finally15;
	__catch15_g_error:
	{
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_inner_error_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp30_ = _data_->_error_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_tmp31_ = _data_->_tmp30_->message;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_warning ("libvirt-broker.vala:105: %s", _data_->_tmp31_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_error_free0 (_data_->_error_);
#line 2272 "libvirt-broker.c"
	}
	__finally15:
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_g_object_unref0 (_data_->connection);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		block30_data_unref (_data_->_data30_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->_data30_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_clear_error (&_data_->_inner_error_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		return FALSE;
#line 2289 "libvirt-broker.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp32_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp32_ = _data_->self->priv->connections;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp33_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp33_ = _data_->_data30_->source;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp34_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp34_ = boxes_collection_source_get_name (_data_->_tmp33_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp35_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp36_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp36_ = _data_->connection;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp37_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp37_ = _g_object_ref0 (_data_->_tmp36_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_hash_table_insert (_data_->_tmp32_, _data_->_tmp35_, _data_->_tmp37_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp38_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp38_ = _data_->connection;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp39_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp39_ = gvir_connection_get_domains (_data_->_tmp38_);
#line 2325 "libvirt-broker.c"
	{
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		_data_->domain_collection = _data_->_tmp39_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		for (_data_->domain_it = _data_->domain_collection; _data_->domain_it != NULL; _data_->domain_it = _data_->domain_it->next) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp40_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->_tmp40_ = _g_object_ref0 ((GVirDomain*) _data_->domain_it->data);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
			_data_->domain = _data_->_tmp40_;
#line 2337 "libvirt-broker.c"
			{
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp41_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp41_ = _data_->_data30_->source;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp42_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp42_ = _data_->connection;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp43_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_tmp43_ = _data_->domain;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_data_->_state_ = 6;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				boxes_libvirt_broker_try_add_existing_domain (_data_->self, _data_->_tmp41_, _data_->_tmp42_, _data_->_tmp43_, boxes_libvirt_broker_add_source_ready, _data_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				return FALSE;
#line 2357 "libvirt-broker.c"
				_state_6:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				boxes_libvirt_broker_try_add_existing_domain_finish (_data_->self, _data_->_res_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
				_g_object_unref0 (_data_->domain);
#line 2363 "libvirt-broker.c"
			}
		}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		__g_list_free__g_object_unref0_0 (_data_->domain_collection);
#line 2368 "libvirt-broker.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp44_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp44_ = _data_->connection;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_signal_connect_object (_data_->_tmp44_, "domain-removed", (GCallback) ___lambda12__gvir_connection_domain_removed, _data_->self, 0);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp45_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp45_ = _data_->connection;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_signal_connect_data (_data_->_tmp45_, "domain-added", (GCallback) ___lambda80__gvir_connection_domain_added, block30_data_ref (_data_->_data30_), (GClosureNotify) block30_data_unref, 0);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp46_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_tmp46_ = _data_->_data30_->source;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_state_ = 7;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_libvirt_broker_parent_class)->add_source (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_tmp46_, boxes_libvirt_broker_add_source_ready, _data_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 2392 "libvirt-broker.c"
	_state_7:
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	BOXES_BROKER_CLASS (boxes_libvirt_broker_parent_class)->add_source_finish (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, BOXES_TYPE_BROKER, BoxesBroker), _data_->_res_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_object_unref0 (_data_->connection);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	block30_data_unref (_data_->_data30_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_data_->_data30_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	if (_data_->_state_ == 0) {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2406 "libvirt-broker.c"
	} else {
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2410 "libvirt-broker.c"
	}
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_object_unref (_data_->_async_result);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	return FALSE;
#line 2416 "libvirt-broker.c"
}


static void boxes_libvirt_broker_class_init (BoxesLibvirtBrokerClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	boxes_libvirt_broker_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtBrokerPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	((BoxesBrokerClass *) klass)->add_source = boxes_libvirt_broker_real_add_source;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	((BoxesBrokerClass *) klass)->add_source_finish = boxes_libvirt_broker_real_add_source_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_broker_finalize;
#line 2431 "libvirt-broker.c"
}


static void boxes_libvirt_broker_instance_init (BoxesLibvirtBroker * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self->priv = BOXES_LIBVIRT_BROKER_GET_PRIVATE (self);
#line 2438 "libvirt-broker.c"
}


static void boxes_libvirt_broker_finalize (GObject* obj) {
	BoxesLibvirtBroker * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	_g_hash_table_unref0 (self->priv->connections);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-broker.vala"
	G_OBJECT_CLASS (boxes_libvirt_broker_parent_class)->finalize (obj);
#line 2450 "libvirt-broker.c"
}


GType boxes_libvirt_broker_get_type (void) {
	static volatile gsize boxes_libvirt_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtBroker), 0, (GInstanceInitFunc) boxes_libvirt_broker_instance_init, NULL };
		GType boxes_libvirt_broker_type_id;
		boxes_libvirt_broker_type_id = g_type_register_static (BOXES_TYPE_BROKER, "BoxesLibvirtBroker", &g_define_type_info, 0);
		g_once_init_leave (&boxes_libvirt_broker_type_id__volatile, boxes_libvirt_broker_type_id);
	}
	return boxes_libvirt_broker_type_id__volatile;
}



